# A Hybrid Gravity and Route Choice Model to Assess Vector Traffic in Large-Scale Systems

This package provides an implementation of the hybrid gravity and route choice
model introduced by [Fischer et al. (2019)][REF]. If you use this package 
in research that leads to a scientific publication, we kindly ask you to 
cite the publication.

The package is licensed under the [LGPL-v3][LGPL]. For documentation please refer to
[the project's documentation page on github][DOC]. Please report any bugs on 
[the project's bug tracker][BUG]. You are welcome to adjust the provided
files to your needs and to improve the code. It is encouraged that you share any 
improvements on [the github page][GIT] if possible.

[REF]: https://arxiv.org/abs/1909.08811
[LGPL]: https://opensource.org/licenses/lgpl-3.0.html
[DOC]: https://vemomoto.github.io/hybrid_vector_model
[GIT]: https://github.com/vemomoto/vemomoto/
[BUG]: https://github.com/vemomoto/vemomoto/issues